package com.esignlive.guidance.forum;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;

import org.json.JSONException;
import org.json.JSONObject;

import com.silanis.esl.sdk.AuthenticationClient;
import com.silanis.esl.sdk.Document;
import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.SignerId;
import com.silanis.esl.sdk.SigningStatus;

public class _12_10_1 {
	public static final String API_KEY = "api_key";
	public static final String API_URL = "https://sandbox.esignlive.com/api";
	public static final String BASE_URL = "https://sandbox.esignlive.com/";
	public static final String PACKAGE_ID = "SpVUG-q6ggZYVuOed19uI3baxfo=";
	public static final String SIGNER_ID = "esignguide1@mailinator.com";

	public static void main(String[] args) {
		EslClient eslClient = new EslClient(API_KEY, API_URL);
		
		// #1. create signer sesion token
		String signerAuthToken = eslClient.getAuthenticationTokensService().createSignerAuthenticationToken(PACKAGE_ID,
				SIGNER_ID);
		AuthenticationClient authenticationClient = new AuthenticationClient(BASE_URL);
		String signerSessionId = authenticationClient.getSessionIdForSignerAuthenticationToken(signerAuthToken);
		System.out.println(signerSessionId);

		// #2. loop through all documents
		DocumentPackage package1 = eslClient.getPackage(new PackageId(PACKAGE_ID));

		for (Document document : package1.getDocuments()) {
			SigningStatus signingStatus = eslClient.getSigningStatus(new PackageId(PACKAGE_ID), new SignerId(SIGNER_ID),
					document.getId());
			if (signingStatus != SigningStatus.SIGNING_COMPLETE) {
				try {
					confirmDocument(
							API_URL + "/packages/" + PACKAGE_ID + "/documents/" + document.getId() + "/actions?",
							signerSessionId);
				} catch (Exception e) {
					//deal with exception
					System.out.println(e.getMessage());
				}
			}
		}

		// #3. get signer signing status
		SigningStatus signingStatus = eslClient.getSigningStatus(new PackageId(PACKAGE_ID), new SignerId(SIGNER_ID),
				null);
		System.out.println(signingStatus);

	}

	public static void confirmDocument(String url, String sessionToken)
			throws RuntimeException, IOException, JSONException {
		URL client = new URL(url);
		HttpURLConnection conn = (HttpURLConnection) client.openConnection();
		conn.setRequestProperty("Cookie", "ESIGNLIVE_SESSION_ID=" + sessionToken);
		conn.setRequestProperty("Accept", "application/json");
		conn.setRequestMethod("POST");

		int responseCode = ((HttpURLConnection) conn).getResponseCode();

		if (responseCode == 200) {
			return;
		} else {
			BufferedReader in = new BufferedReader(new InputStreamReader(conn.getInputStream()));
			String inputLine;
			StringBuffer response = new StringBuffer();

			while ((inputLine = in.readLine()) != null) {
				response.append(inputLine);
			}

			in.close();
			conn.disconnect();

			if (responseCode == 403) {
				JSONObject json = new JSONObject(response.toString());
				String message = json.getString("message");
				if (message.contains("already been confirmed")) {
					return;
				}
			} else {
				throw new RuntimeException(response.toString());
			}
		}

	}

}
